Learn R Programming

ksformat (version 0.3.5)

.invalue_apply: Apply Invalue Format (Reverse Formatting)

Description

Applies an invalue format to convert formatted labels back to values.

Usage

.invalue_apply(x, invalue, na_if = NULL)

Value

Vector with values (type depends on invalue's target_type)

Arguments

x

Character vector of labels to convert

invalue

A ks_invalue object or a character string naming an invalue format in the global format library.

na_if

Character vector. Additional values to treat as NA