Marks a format label string so it will be evaluated as an R expression
at apply-time (fput), even when it does not contain
.x1, .x2, etc. placeholders.
Details
This is useful when a label should call a function that does not need
positional .xN arguments.
The expression is evaluated in the caller's environment of
fput, so user-defined functions are accessible.
Labels containing .x1, .x2, etc. are still evaluated
automatically without needing e().