fclear: Remove Format(s) from Library

View source: R/utilities.R

fclearR Documentation

Remove Format(s) from Library

Description

Removes one or all formats from the global format library. When called without arguments, clears all formats. When called with a name, removes only that format.

Usage

fclear(name = NULL)

Arguments

name

Character. Optional name of a specific format to remove. If NULL (default), removes all formats.

Value

Invisible NULL

Examples

fnew("M" = "Male", "F" = "Female", name = "sex")
fclear("sex")   # remove one format
fclear()        # remove all formats

ksformat documentation built on May 21, 2026, 9:07 a.m.