| fclear | R Documentation |
Removes one or all formats from the global format library. When called without arguments, clears all formats. When called with a name, removes only that format.
fclear(name = NULL)
name |
Character. Optional name of a specific format to remove.
If |
Invisible NULL
fnew("M" = "Male", "F" = "Female", name = "sex")
fclear("sex") # remove one format
fclear() # remove all formats
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.