Learn R Programming

ksformat (version 0.3.5)

fclear: Remove Format(s) from Library

Description

Removes one or all formats from the global format library. When called without arguments, clears all formats. When called with a name, removes only that format.

Usage

fclear(name = NULL)

Value

Invisible NULL

Arguments

name

Character. Optional name of a specific format to remove. If NULL (default), removes all formats.

Examples

Run this code
fnew("M" = "Male", "F" = "Female", name = "sex")
fclear("sex")   # remove one format
fclear()        # remove all formats

Run the code above in your browser using DataLab