flist: List Format Names from Library

View source: R/utilities.R

flistR Documentation

List Format Names from Library

Description

Returns a character vector of all format and invalue names currently registered in the global format library.

Usage

flist()

Value

A character vector of registered format names, sorted alphabetically. Returns character(0) if the library is empty.

Examples

fnew("M" = "Male", "F" = "Female", name = "sex")
flist()
fclear()

ksformat documentation built on May 21, 2026, 9:07 a.m.