| flist | R Documentation |
Returns a character vector of all format and invalue names currently registered in the global format library.
flist()
A character vector of registered format names, sorted alphabetically.
Returns character(0) if the library is empty.
fnew("M" = "Male", "F" = "Female", name = "sex")
flist()
fclear()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.