Learn R Programming

ksformat (version 0.3.5)

fprint: Print Format(s) from Library

Description

Displays format information from the global format library. When called without arguments, lists all registered format names. When called with a name, displays the full definition of that format.

Usage

fprint(name = NULL)

Value

Invisible NULL. This function is for display only.

Arguments

name

Character. Optional name of a specific format to display. If NULL (default), lists all registered formats.

Examples

Run this code
fnew("M" = "Male", "F" = "Female", name = "sex")
fprint()         # list all formats
fprint("sex")    # show specific format
fclear()

Run the code above in your browser using DataLab