ksformat_cheatsheet: Open the ksformat cheat sheet

View source: R/cheatsheet.R

ksformat_cheatsheetR Documentation

Open the ksformat cheat sheet

Description

Opens the package cheat sheet in the default browser (HTML) or viewer (PDF). The files are installed under system.file("doc", ..., package = "ksformat").

Usage

ksformat_cheatsheet(format = c("html", "pdf"))

Arguments

format

Character: "html" (default) or "pdf". Which version to open.

Value

Invisibly, the path to the opened file. If the file is not found, an error is thrown.

Examples

## Not run: 
ksformat_cheatsheet()           # open HTML in browser
ksformat_cheatsheet("pdf")      # open PDF

## End(Not run)

ksformat documentation built on May 21, 2026, 9:07 a.m.