| ksformat_cheatsheet | R Documentation |
Opens the package cheat sheet in the default browser (HTML) or viewer (PDF).
The files are installed under system.file("doc", ..., package = "ksformat").
ksformat_cheatsheet(format = c("html", "pdf"))
format |
Character: |
Invisibly, the path to the opened file. If the file is not found, an error is thrown.
## Not run:
ksformat_cheatsheet() # open HTML in browser
ksformat_cheatsheet("pdf") # open PDF
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.