Learn R Programming

ksformat (version 0.3.5)

ksformat_cheatsheet: Open the ksformat cheat sheet

Description

Opens the package cheat sheet in the default browser (HTML) or viewer (PDF). The files are installed under system.file("doc", ..., package = "ksformat").

Usage

ksformat_cheatsheet(format = c("html", "pdf"))

Value

Invisibly, the path to the opened file. If the file is not found, an error is thrown.

Arguments

format

Character: "html" (default) or "pdf". Which version to open.

Examples

Run this code
# \donttest{
ksformat_cheatsheet()           # open HTML in browser
ksformat_cheatsheet("pdf")      # open PDF
# }

Run the code above in your browser using DataLab